# Модуль "Ход конём"
![а где](knight.png)
Модуль "Ход конём" - это python модуль, позволяющий вычислить количество ходов необходимо шахматному коню чтобы дойти из одной клетки в другую, а так же узнать, через сколько ходов два коня будут в зоне атаки друг друга

---
## Установка

Для установки данного пакета потребуется библиотека [pip](https://pip.pypa.io/en/stable/).

```bash
pip install -i https://test.pypi.org/simple/ 
```
---
## Использование


### Функции
**main**(func, first_c, second_c) - считывает из командной строки строку func, по которой можно понять, в какую из функций пользователь хочет передать данные, а так же 4 элемента, которые соответствуют координатам клеток.

**knight_move**(start: Tuple[int, int], finish: Tuple[int, int]) -> int - на вход получает 2 кортежа, в каждом из которых на 1 месте буква от A до H, на втором цифра от 1 до 8, которые в сумме обозначают координаты начальной и конечной клетки, возвращает целое число - минимальное число ходов, необходимое коню, чтобы добраться из первой клетки во вторую.

**knights_collision**(first: Tuple[int, int], second: Tuple[int, int]) -> int - на вход получает то же, что и первая функция, но возвращает минимальное число ходов, необходимое двум коням, расположенным во введённых клетках, чтобы оказаться в зоне атаки друг друга.

**defence_knight_move**(f_1, f_2, s_1, s_2) - на вход получает координаты, как и knight_move, проверяет их на корректность.


### Примеры

```python
>>>__main__.py k_m a 4 f 5
4
>>>__main__.py k_c b 4 f 8
2
>>>__main__.py k_m g 9 f 8
ValueError
>>>__main__.py k_c g 5 f 0
ValueError
```
[Вверх](#модуль-ход-конём)

## Лицензии
[MIT](https://opensource.org/licenses/MIT)